/*
 * This routine does a standard reduction of all Xcu resources
 * for String conversion.  It massages the input string in three
 * ways:
 *	1) convert all upper to lower case
 *	2) squeeze out all underscores
 *	3) remove any prefixes
 * It then returns the quark corresponding to the transformed string.
 * Thus, all of the following are equivalent when used as strings to
 * represent the XcuCellSequence resource, XcuRANDOM_COLOR:
 * "XcuRANDOM_COLOR", "random_color", "RandomColor", etc.
 * They are all reduced to "randomcolor".
 */

#include <X11/Intrinsic.h>
#include <ctype.h>

XrmQuark
XcuSimplifyArg (arg, prefix)
    String arg ;
    String prefix ;
{
int	i, j ;
int	arg_length = strlen(arg) ;
int	prefix_length = strlen(prefix) ;
String	lowerName = (String) XtMalloc (arg_length+1) ;
String	name_ptr ;

for (i=0,j=0; i<=arg_length; i++)
    {
    char c = arg[i] ;
    lowerName[j] = isupper(c) ? (char) tolower(c) : c ;
    if (lowerName[j] != '_') /* squeeze out underscores */
	j++ ;
    }
while (lowerName[j] == '_') /* remove trailing underscores */
    lowerName[j--] = '\0' ;

name_ptr = lowerName ; /* remove prefixes */
if (strncmp (lowerName, prefix, prefix_length) == 0)
    name_ptr += prefix_length ;

XtFree (lowerName) ;
return XrmStringToQuark(name_ptr) ;
}

